#####
Usage
#####

************
Data loading
************

Please refer to the `data_loader.ipynb <https://nbviewer.org/github/serpentine-h2020/serpentine/blob/main/notebooks/sep_analysis_tools/data_loader.ipynb>`_ Jupyter Notebook provided through the `SERPENTINE project <https://serpentine-h2020.eu>`_ for examples of loading data from different spacecraft.

*********
SEP tools
*********

The main tools for SEP analysis provided in `seppy` are intended to be used in the corresponding Jupyter Notebooks provided through the `SERPENTINE project <https://serpentine-h2020.eu>`_:

* `dynamic_spectrum.ipynb <https://nbviewer.org/github/serpentine-h2020/serpentine/blob/main/notebooks/sep_analysis_tools/dynamic_spectrum.ipynb>`_: Dynamic spectrum plotter for different charged particle species measured by the current heliospheric spacecraft fleet and radio observations.
* `onset_determination.ipynb <https://nbviewer.org/github/serpentine-h2020/serpentine/blob/main/notebooks/sep_analysis_tools/onset_determination.ipynb>`_: SEP event onset time determination using the established Poisson-CUSUM method.
* `time_shift_analysis.ipynb <https://nbviewer.org/github/serpentine-h2020/serpentine/blob/main/notebooks/sep_analysis_tools/time_shift_analysis.ipynb>`_: Interactive determination of solar release time for an SEP event observed in different energy channels.

They can be download and run locally (see `https://github.com/serpentine-h2020/serpentine <https://github.com/serpentine-h2020/serpentine>`_ for instructions) or in the cloud on the project's `JupyterHub server <https://serpentine-h2020.eu/hub/>`_.